summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorschmidt <douglascraigschmidt@users.noreply.github.com>1996-12-09 00:48:37 +0000
committerschmidt <douglascraigschmidt@users.noreply.github.com>1996-12-09 00:48:37 +0000
commit43d61970c52d914b904a26b9f99efb1559d21b35 (patch)
tree37730b31e8f345370ceb1796fc0ef7b680245978
parent414eacdf84def957356627347beae45d1f93e04a (diff)
downloadATCD-43d61970c52d914b904a26b9f99efb1559d21b35.tar.gz
new
-rw-r--r--ace/ACE.cpp6
-rw-r--r--ace/OS.h12
-rw-r--r--ace/Remote_Name_Space.cpp5
-rw-r--r--ace/Remote_Name_Space.h4
-rw-r--r--ace/SV_Semaphore_Complex.cpp8
-rw-r--r--ace/SV_Semaphore_Complex.h30
-rw-r--r--ace/SV_Semaphore_Complex.i22
-rw-r--r--ace/SV_Semaphore_Simple.cpp10
-rw-r--r--ace/SV_Semaphore_Simple.h30
-rw-r--r--ace/SV_Semaphore_Simple.i20
-rw-r--r--ace/Service_Manager.cpp2
-rw-r--r--ace/Signal.cpp20
12 files changed, 87 insertions, 82 deletions
diff --git a/ace/ACE.cpp b/ace/ACE.cpp
index 20078237762..0efc72db3f4 100644
--- a/ace/ACE.cpp
+++ b/ace/ACE.cpp
@@ -21,6 +21,7 @@ ACE::register_stdin_handler (ACE_Event_Handler *eh,
// Keep compilers happy.
flags = flags;
thr_mgr = thr_mgr;
+ reactor = reactor;
return reactor->register_handler (ACE_STDIN, eh, ACE_Event_Handler::READ_MASK);
#endif /* ACE_WIN32 */
}
@@ -656,8 +657,8 @@ ACE::bind_port (ACE_HANDLE handle)
sockaddr_in sin;
// This should be a constant, so I hope they never change the number
// of bits in a port number!
- const int MAX_SHORT = 65535;
- static int upper_limit = MAX_SHORT;
+ const u_short MAX_SHORT = 65535;
+ static u_short upper_limit = MAX_SHORT;
int lower_limit = IPPORT_RESERVED;
int round_trip = upper_limit;
@@ -757,6 +758,7 @@ ACE::set_handle_limit (int new_limit)
return ACE_OS::setrlimit (RLIMIT_NOFILE, &rl);
#else
+ new_limit = new_limit;
ACE_NOTSUP_RETURN (-1);
#endif /* ACE_WIN32 */
}
diff --git a/ace/OS.h b/ace/OS.h
index 0ee86f4d56f..6bb3d27a3b4 100644
--- a/ace/OS.h
+++ b/ace/OS.h
@@ -106,12 +106,6 @@
// Here are all ACE-specific global declarations needed throughout
// ACE.
-#if defined (ACE_HAS_USING_KEYWORD)
-#define ACE_USING using
-#else
-#define ACE_USING
-#endif /* ACE_HAS_USING_KEYWORD */
-
// Helpful dump macros.
#define ACE_BEGIN_DUMP "\n====\n(%P|%t|%x)"
#define ACE_END_DUMP "====\n"
@@ -179,6 +173,12 @@ typedef int key_t;
#include "ace/Time_Value.h"
+#if defined (ACE_HAS_USING_KEYWORD)
+#define ACE_USING using
+#else
+#define ACE_USING
+#endif /* ACE_HAS_USING_KEYWORD */
+
// The following is necessary since many C++ compilers don't support
// typedef'd types inside of classes used as formal template
// arguments... ;-(. Luckily, using the C++ preprocessor I can hide
diff --git a/ace/Remote_Name_Space.cpp b/ace/Remote_Name_Space.cpp
index cc9f42041dd..a3813ebf610 100644
--- a/ace/Remote_Name_Space.cpp
+++ b/ace/Remote_Name_Space.cpp
@@ -5,7 +5,7 @@
#include "ace/Remote_Name_Space.h"
int
-ACE_Remote_Name_Space::open (const char *servername, int port)
+ACE_Remote_Name_Space::open (const char *servername, u_short port)
{
ACE_TRACE ("ACE_Remote_Name_Space::open");
ACE_INET_Addr servaddr;
@@ -26,7 +26,8 @@ ACE_Remote_Name_Space::ACE_Remote_Name_Space (void)
ACE_TRACE ("ACE_Remote_Name_Space::ACE_Remote_Name_Space");
}
-ACE_Remote_Name_Space::ACE_Remote_Name_Space (const char *hostname, int port)
+ACE_Remote_Name_Space::ACE_Remote_Name_Space (const char *hostname,
+ u_short port)
{
ACE_TRACE ("ACE_Remote_Name_Space::ACE_Remote_Name_Space");
if (this->open (hostname, port) == -1)
diff --git a/ace/Remote_Name_Space.h b/ace/Remote_Name_Space.h
index a81c15b6bbb..d6010250c07 100644
--- a/ace/Remote_Name_Space.h
+++ b/ace/Remote_Name_Space.h
@@ -45,12 +45,12 @@ public:
ACE_Remote_Name_Space (void);
// "Do-nothing" constructor.
- ACE_Remote_Name_Space (const char *hostname, int port);
+ ACE_Remote_Name_Space (const char *hostname, u_short port);
// Specifies the scope of this namespace, opens and memory-maps the
// associated file (if accessible) or contacts the dedicated name
// server process for NET_LOCAL namespace.
- int open (const char *servername, int port);
+ int open (const char *servername, u_short port);
// Specifies the scope of this namespace, opens and memory-maps the
// associated file (if accessible) or contacts the dedicated name
// server process for NET_LOCAL namespace.
diff --git a/ace/SV_Semaphore_Complex.cpp b/ace/SV_Semaphore_Complex.cpp
index 9f65a36499e..09aac60b0bf 100644
--- a/ace/SV_Semaphore_Complex.cpp
+++ b/ace/SV_Semaphore_Complex.cpp
@@ -58,7 +58,7 @@ int
ACE_SV_Semaphore_Complex::open (key_t k,
int create,
int initial_value,
- int nsems,
+ u_short nsems,
int perms)
{
ACE_TRACE ("ACE_SV_Semaphore_Complex::open");
@@ -148,7 +148,7 @@ int
ACE_SV_Semaphore_Complex::open (const char *name,
int flags,
int initial_value,
- int nsems,
+ u_short nsems,
int perms)
{
ACE_TRACE ("ACE_SV_Semaphore_Complex::open");
@@ -202,7 +202,7 @@ ACE_SV_Semaphore_Complex::close (void)
ACE_SV_Semaphore_Complex::ACE_SV_Semaphore_Complex (key_t k,
int flags,
int initial_value,
- int nsems,
+ u_short nsems,
int perms)
{
ACE_TRACE ("ACE_SV_Semaphore_Complex::ACE_SV_Semaphore_Complex");
@@ -213,7 +213,7 @@ ACE_SV_Semaphore_Complex::ACE_SV_Semaphore_Complex (key_t k,
ACE_SV_Semaphore_Complex::ACE_SV_Semaphore_Complex (const char *name,
int flags,
int initial_value,
- int nsems,
+ u_short nsems,
int perms)
{
ACE_TRACE ("ACE_SV_Semaphore_Complex::ACE_SV_Semaphore_Complex");
diff --git a/ace/SV_Semaphore_Complex.h b/ace/SV_Semaphore_Complex.h
index a0a198f385c..edfd13bf65b 100644
--- a/ace/SV_Semaphore_Complex.h
+++ b/ace/SV_Semaphore_Complex.h
@@ -62,19 +62,19 @@ public:
ACE_SV_Semaphore_Complex (key_t key,
int create = ACE_SV_Semaphore_Complex::ACE_CREATE,
int initial_value = 1,
- int nsems = 1,
+ u_short nsems = 1,
int perms = ACE_DEFAULT_FILE_PERMS);
ACE_SV_Semaphore_Complex (const char *name,
int create = ACE_SV_Semaphore_Complex::ACE_CREATE,
int initial_value = 1,
- int nsems = 1,
+ u_short nsems = 1,
int perms = ACE_DEFAULT_FILE_PERMS);
~ACE_SV_Semaphore_Complex (void);
int open (const char *name,
int flags = ACE_SV_Semaphore_Simple::ACE_CREATE,
int initial_value = 1,
- int nsems = 1,
+ u_short nsems = 1,
int perms = ACE_DEFAULT_FILE_PERMS);
// Open or create an array of SV_Semaphores. We return 0 if all is
// OK, else -1.
@@ -82,7 +82,7 @@ public:
int open (key_t key,
int flags = ACE_SV_Semaphore_Simple::ACE_CREATE,
int initial_value = 1,
- int nsems = 1,
+ u_short nsems = 1,
int perms = ACE_DEFAULT_FILE_PERMS);
// Open or create an array of SV_Semaphores. We return 0 if all is
// OK, else -1.
@@ -96,34 +96,34 @@ public:
// = Semaphore acquire and release methods.
- int acquire (int n = 0, int flags = 0) const;
+ int acquire (u_short n = 0, int flags = 0) const;
// Acquire the semaphore.
- int acquire_read (int n = 0, int flags = 0) const;
+ int acquire_read (u_short n = 0, int flags = 0) const;
// Acquire a semaphore for reading.
- int acquire_write (int n = 0, int flags = 0) const;
+ int acquire_write (u_short n = 0, int flags = 0) const;
// Acquire a semaphore for writing
- int tryacquire (int n = 0, int flags = 0) const;
+ int tryacquire (u_short n = 0, int flags = 0) const;
// Try to acquire the semaphore.
- int tryacquire_read (int n = 0, int flags = 0) const;
+ int tryacquire_read (u_short n = 0, int flags = 0) const;
// Try to acquire the semaphore for reading.
- int tryacquire_write (int n = 0, int flags = 0) const;
+ int tryacquire_write (u_short n = 0, int flags = 0) const;
// Try to acquire the semaphore for writing.
- int release (int n = 0, int flags = 0) const;
+ int release (u_short n = 0, int flags = 0) const;
// Release the semaphore.
// = Semaphore operation methods.
- int op (int val, int n = 0, int flags = 0) const;
- int op (sembuf op_vec[], int n) const;
+ int op (int val, u_short n = 0, int flags = 0) const;
+ int op (sembuf op_vec[], u_short n) const;
// = Semaphore control methods.
- int control (int cmd, semun arg, int n = 0) const;
- int control (int cmd, int value = 0, int n = 0) const;
+ int control (int cmd, semun arg, u_short n = 0) const;
+ int control (int cmd, int value = 0, u_short n = 0) const;
// = Upgrade access control...
ACE_USING ACE_SV_Semaphore_Simple::get_id;
diff --git a/ace/SV_Semaphore_Complex.i b/ace/SV_Semaphore_Complex.i
index b85fd09ec6d..deabeb2f4d4 100644
--- a/ace/SV_Semaphore_Complex.i
+++ b/ace/SV_Semaphore_Complex.i
@@ -6,77 +6,77 @@
#include "ace/Trace.h"
inline int
-ACE_SV_Semaphore_Complex::acquire (int n, int flags) const
+ACE_SV_Semaphore_Complex::acquire (u_short n, int flags) const
{
ACE_TRACE ("ACE_SV_Semaphore_Complex::acquire");
return ACE_SV_Semaphore_Simple::acquire (n + 2, flags);
}
inline int
-ACE_SV_Semaphore_Complex::acquire_read (int n, int flags) const
+ACE_SV_Semaphore_Complex::acquire_read (u_short n, int flags) const
{
ACE_TRACE ("ACE_SV_Semaphore_Complex::acquire_read");
return this->acquire (n, flags);
}
inline int
-ACE_SV_Semaphore_Complex::acquire_write (int n, int flags) const
+ACE_SV_Semaphore_Complex::acquire_write (u_short n, int flags) const
{
ACE_TRACE ("ACE_SV_Semaphore_Complex::acquire_write");
return this->acquire (n, flags);
}
inline int
-ACE_SV_Semaphore_Complex::tryacquire (int n, int flags) const
+ACE_SV_Semaphore_Complex::tryacquire (u_short n, int flags) const
{
ACE_TRACE ("ACE_SV_Semaphore_Complex::tryacquire");
return ACE_SV_Semaphore_Simple::tryacquire (n + 2, flags);
}
inline int
-ACE_SV_Semaphore_Complex::tryacquire_read (int n, int flags) const
+ACE_SV_Semaphore_Complex::tryacquire_read (u_short n, int flags) const
{
ACE_TRACE ("ACE_SV_Semaphore_Complex::tryacquire_read");
return this->tryacquire (n, flags);
}
inline int
-ACE_SV_Semaphore_Complex::tryacquire_write (int n, int flags) const
+ACE_SV_Semaphore_Complex::tryacquire_write (u_short n, int flags) const
{
ACE_TRACE ("ACE_SV_Semaphore_Complex::tryacquire_write");
return this->tryacquire (n, flags);
}
inline int
-ACE_SV_Semaphore_Complex::release (int n, int flags) const
+ACE_SV_Semaphore_Complex::release (u_short n, int flags) const
{
ACE_TRACE ("ACE_SV_Semaphore_Complex::release");
return ACE_SV_Semaphore_Simple::release (n + 2, flags);
}
inline int
-ACE_SV_Semaphore_Complex::op (int val, int n, int flags) const
+ACE_SV_Semaphore_Complex::op (int val, u_short n, int flags) const
{
ACE_TRACE ("ACE_SV_Semaphore_Complex::op");
return ACE_SV_Semaphore_Simple::op (val, n + 2, flags);
}
inline int
-ACE_SV_Semaphore_Complex::op (sembuf op_vec[], int n) const
+ACE_SV_Semaphore_Complex::op (sembuf op_vec[], u_short n) const
{
ACE_TRACE ("ACE_SV_Semaphore_Complex::op");
return ACE_SV_Semaphore_Simple::op (op_vec, n + 2);
}
inline int
-ACE_SV_Semaphore_Complex::control (int cmd, semun arg, int n) const
+ACE_SV_Semaphore_Complex::control (int cmd, semun arg, u_short n) const
{
ACE_TRACE ("ACE_SV_Semaphore_Complex::control");
return ACE_SV_Semaphore_Simple::control (cmd, arg, n + 2);
}
inline int
-ACE_SV_Semaphore_Complex::control (int cmd, int value, int n) const
+ACE_SV_Semaphore_Complex::control (int cmd, int value, u_short n) const
{
ACE_TRACE ("ACE_SV_Semaphore_Complex::control");
return ACE_SV_Semaphore_Simple::control (cmd, value, n + 2);
diff --git a/ace/SV_Semaphore_Simple.cpp b/ace/SV_Semaphore_Simple.cpp
index e593d4cb36b..5506866b5da 100644
--- a/ace/SV_Semaphore_Simple.cpp
+++ b/ace/SV_Semaphore_Simple.cpp
@@ -45,7 +45,7 @@ ACE_SV_Semaphore_Simple::init (key_t k, int i)
// specific amount (positive or negative; amount can`t be zero).
int
-ACE_SV_Semaphore_Simple::op (int val, int n, int flags) const
+ACE_SV_Semaphore_Simple::op (int val, u_short n, int flags) const
{
ACE_TRACE ("ACE_SV_Semaphore_Simple::op");
sembuf op_op;
@@ -68,7 +68,7 @@ int
ACE_SV_Semaphore_Simple::open (key_t k,
int flags,
int initial_value,
- int n,
+ u_short n,
int perms)
{
ACE_TRACE ("ACE_SV_Semaphore_Simple::open");
@@ -99,7 +99,7 @@ ACE_SV_Semaphore_Simple::open (key_t k,
ACE_SV_Semaphore_Simple::ACE_SV_Semaphore_Simple (key_t k,
int flags,
int initial_value,
- int n,
+ u_short n,
int perms)
: key_ (k)
{
@@ -150,7 +150,7 @@ int
ACE_SV_Semaphore_Simple::open (const char *name,
int flags,
int initial_value,
- int n,
+ u_short n,
int perms)
{
ACE_TRACE ("ACE_SV_Semaphore_Simple::open");
@@ -168,7 +168,7 @@ ACE_SV_Semaphore_Simple::open (const char *name,
ACE_SV_Semaphore_Simple::ACE_SV_Semaphore_Simple (const char *name,
int flags,
int initial_value,
- int n,
+ u_short n,
int perms)
{
ACE_TRACE ("ACE_SV_Semaphore_Simple::ACE_SV_Semaphore_Simple");
diff --git a/ace/SV_Semaphore_Simple.h b/ace/SV_Semaphore_Simple.h
index 04100612e21..3eacce1be98 100644
--- a/ace/SV_Semaphore_Simple.h
+++ b/ace/SV_Semaphore_Simple.h
@@ -38,25 +38,25 @@ public:
ACE_SV_Semaphore_Simple (key_t key,
int flags = ACE_SV_Semaphore_Simple::ACE_CREATE,
int initial_value = 1,
- int nsems = 1,
+ u_short nsems = 1,
int perms = ACE_DEFAULT_FILE_PERMS);
ACE_SV_Semaphore_Simple (const char *name,
int flags = ACE_SV_Semaphore_Simple::ACE_CREATE,
int initial_value = 1,
- int nsems = 1,
+ u_short nsems = 1,
int perms = ACE_DEFAULT_FILE_PERMS);
~ACE_SV_Semaphore_Simple (void);
int open (const char *name,
int flags = ACE_SV_Semaphore_Simple::ACE_CREATE,
int initial_value = 1,
- int nsems = 1,
+ u_short nsems = 1,
int perms = ACE_DEFAULT_FILE_PERMS);
int open (key_t key,
int flags = ACE_SV_Semaphore_Simple::ACE_CREATE,
int initial_value = 1,
- int nsems = 1,
+ u_short nsems = 1,
int perms = ACE_DEFAULT_FILE_PERMS);
// Open or create one or more SV_Semaphores. We return 0 if all is
// OK, else -1.
@@ -73,27 +73,27 @@ public:
// Most other processes should use close() below.
// = Semaphore acquire and release methods.
- int acquire (int n = 0, int flags = 0) const;
+ int acquire (u_short n = 0, int flags = 0) const;
// Wait until a ACE_SV_Semaphore's value is greater than 0, the
// decrement it by 1 and return. Dijkstra's P operation, Tannenbaums
// DOWN operation.
- int acquire_read (int n = 0, int flags = 0) const;
+ int acquire_read (u_short n = 0, int flags = 0) const;
// Acquire a semaphore for reading.
- int acquire_write (int n = 0, int flags = 0) const;
+ int acquire_write (u_short n = 0, int flags = 0) const;
// Acquire a semaphore for writing
- int tryacquire (int n = 0, int flags = 0) const;
+ int tryacquire (u_short n = 0, int flags = 0) const;
// Non-blocking version of <acquire>.
- int tryacquire_read (int n = 0, int flags = 0) const;
+ int tryacquire_read (u_short n = 0, int flags = 0) const;
// Try to acquire the semaphore for reading.
- int tryacquire_write (int n = 0, int flags = 0) const;
+ int tryacquire_write (u_short n = 0, int flags = 0) const;
// Try to acquire the semaphore for writing.
- int release (int n = 0, int flags = 0) const;
+ int release (u_short n = 0, int flags = 0) const;
// Increment ACE_SV_Semaphore by one. Dijkstra's V operation,
// Tannenbaums UP operation.
@@ -102,12 +102,12 @@ public:
// General ACE_SV_Semaphore operation. Increment or decrement by a
// specific amount (positive or negative; amount can`t be zero).
- int op (sembuf op_vec[], int nsems) const;
+ int op (sembuf op_vec[], u_short nsems) const;
// General ACE_SV_Semaphore operation on an array of SV_Semaphores.
// = Semaphore control methods.
- int control (int cmd, semun arg, int semnum = 0) const;
- int control (int cmd, int value = 0, int semnum = 0) const;
+ int control (int cmd, semun arg, u_short n = 0) const;
+ int control (int cmd, int value = 0, u_short n = 0) const;
int get_id (void) const;
// Get underlying internal id.
@@ -124,7 +124,7 @@ protected:
int sem_number_;
int init (key_t k = ACE_INVALID_SEM_KEY, int i = -1);
- key_t name_2_key (const char *name);
+ key_t name_2_key (const char *name);
// Convert name to key This function is used internally to create
// keys for the semaphores. A valid name contains letters and
// digits only and MUST start with a letter.
diff --git a/ace/SV_Semaphore_Simple.i b/ace/SV_Semaphore_Simple.i
index e4c9fb8d3e1..ae949204498 100644
--- a/ace/SV_Semaphore_Simple.i
+++ b/ace/SV_Semaphore_Simple.i
@@ -12,11 +12,11 @@
inline int
ACE_SV_Semaphore_Simple::control (int cmd,
semun arg,
- int semnum) const
+ u_short n) const
{
ACE_TRACE ("ACE_SV_Semaphore_Simple::control");
return this->internal_id_ == -1 ?
- -1 : ACE_OS::semctl (this->internal_id_, semnum, cmd, arg);
+ -1 : ACE_OS::semctl (this->internal_id_, n, cmd, arg);
}
// Close a ACE_SV_Semaphore, marking it as invalid for subsequent
@@ -32,7 +32,7 @@ ACE_SV_Semaphore_Simple::close (void)
// General ACE_SV_Semaphore operation on an array of SV_Semaphores.
inline int
-ACE_SV_Semaphore_Simple::op (sembuf op_vec[], int n) const
+ACE_SV_Semaphore_Simple::op (sembuf op_vec[], u_short n) const
{
ACE_TRACE ("ACE_SV_Semaphore_Simple::op");
return this->internal_id_ == -1
@@ -44,21 +44,21 @@ ACE_SV_Semaphore_Simple::op (sembuf op_vec[], int n) const
// DOWN operation.
inline int
-ACE_SV_Semaphore_Simple::acquire (int n, int flags) const
+ACE_SV_Semaphore_Simple::acquire (u_short n, int flags) const
{
ACE_TRACE ("ACE_SV_Semaphore_Simple::acquire");
return this->op (-1, n, flags);
}
inline int
-ACE_SV_Semaphore_Simple::acquire_read (int n, int flags) const
+ACE_SV_Semaphore_Simple::acquire_read (u_short n, int flags) const
{
ACE_TRACE ("ACE_SV_Semaphore_Simple::acquire_read");
return this->acquire (n, flags);
}
inline int
-ACE_SV_Semaphore_Simple::acquire_write (int n, int flags) const
+ACE_SV_Semaphore_Simple::acquire_write (u_short n, int flags) const
{
ACE_TRACE ("ACE_SV_Semaphore_Simple::acquire_write");
return this->acquire (n, flags);
@@ -67,7 +67,7 @@ ACE_SV_Semaphore_Simple::acquire_write (int n, int flags) const
// Non-blocking version of acquire().
inline int
-ACE_SV_Semaphore_Simple::tryacquire (int n, int flags) const
+ACE_SV_Semaphore_Simple::tryacquire (u_short n, int flags) const
{
ACE_TRACE ("ACE_SV_Semaphore_Simple::tryacquire");
return this->op (-1, n, flags | IPC_NOWAIT);
@@ -76,7 +76,7 @@ ACE_SV_Semaphore_Simple::tryacquire (int n, int flags) const
// Non-blocking version of acquire().
inline int
-ACE_SV_Semaphore_Simple::tryacquire_read (int n, int flags) const
+ACE_SV_Semaphore_Simple::tryacquire_read (u_short n, int flags) const
{
ACE_TRACE ("ACE_SV_Semaphore_Simple::tryacquire_read");
return this->tryacquire (n, flags);
@@ -85,7 +85,7 @@ ACE_SV_Semaphore_Simple::tryacquire_read (int n, int flags) const
// Non-blocking version of acquire().
inline int
-ACE_SV_Semaphore_Simple::tryacquire_write (int n, int flags) const
+ACE_SV_Semaphore_Simple::tryacquire_write (u_short n, int flags) const
{
ACE_TRACE ("ACE_SV_Semaphore_Simple::tryacquire_write");
return this->tryacquire (n, flags);
@@ -95,7 +95,7 @@ ACE_SV_Semaphore_Simple::tryacquire_write (int n, int flags) const
// Tannenbaums UP operation.
inline int
-ACE_SV_Semaphore_Simple::release (int n, int flags) const
+ACE_SV_Semaphore_Simple::release (u_short n, int flags) const
{
ACE_TRACE ("ACE_SV_Semaphore_Simple::release");
return this->op (1, n, flags);
diff --git a/ace/Service_Manager.cpp b/ace/Service_Manager.cpp
index ceac86b7fc7..834396dff1d 100644
--- a/ace/Service_Manager.cpp
+++ b/ace/Service_Manager.cpp
@@ -90,7 +90,7 @@ ACE_Service_Manager::init (int argc, char *argv[])
this->debug_ = 1;
break;
case 'p':
- local_addr.set (ACE_OS::atoi (getopt.optarg));
+ local_addr.set ((u_short) ACE_OS::atoi (getopt.optarg));
break;
case 's':
this->signum_ = ACE_OS::atoi (getopt.optarg);
diff --git a/ace/Signal.cpp b/ace/Signal.cpp
index e41b8647284..50071e83619 100644
--- a/ace/Signal.cpp
+++ b/ace/Signal.cpp
@@ -12,22 +12,24 @@
#if defined (ACE_HAS_SIG_C_FUNC)
extern "C" void
-ace_signal_handler_dispatch (int signum, siginfo_t *info, ucontext_t *context)
+ace_sig_handler_dispatch (int signum, siginfo_t *info, ucontext_t *context)
{
ACE_TRACE ("ace_signal_handler_dispatch");
ACE_Sig_Handler::dispatch (signum, info, context);
}
extern "C" void
-ace_signal_handlers_dispatch (int signum, siginfo_t *info, ucontext_t *context)
+ace_sig_handlers_dispatch (int signum, siginfo_t *info, ucontext_t *context)
{
ACE_TRACE ("ace_signal_handlers_dispatch");
ACE_Sig_Handlers::dispatch (signum, info, context);
}
-static ACE_SignalHandler ace_dispatcher = ACE_SignalHandler (ace_signal_handler_dispatch);
+static ACE_SignalHandler ace_signal_handler_dispatcher = ACE_SignalHandler (ace_sig_handler_dispatch);
+static ACE_SignalHandler ace_signal_handlers_dispatcher = ACE_SignalHandler (ace_sig_handlers_dispatch);
#else
-static ACE_SignalHandler ace_dispatcher = ACE_SignalHandler (ACE_Sig_Handler::dispatch);
+static ACE_SignalHandler ace_signal_handler_dispatcher = ACE_SignalHandler (ACE_Sig_Handler::dispatch);
+static ACE_SignalHandler ace_signal_handlers_dispatcher = ACE_SignalHandler (ACE_Sig_Handlers::dispatch);
#endif /* ACE_HAS_SIG_C_FUNC */
#if defined (ACE_MT_SAFE)
@@ -184,7 +186,7 @@ ACE_Sig_Handler::register_handler (int signum,
if (new_disp == 0)
new_disp = &sa;
- new_disp->handler (ace_dispatcher);
+ new_disp->handler (ace_signal_handler_dispatcher);
new_disp->flags (new_disp->flags () | SA_SIGINFO);
return new_disp->register_action (signum, old_disp);
}
@@ -407,7 +409,7 @@ ACE_Sig_Handlers::register_handler (int signum,
// Check whether we are already in control of the signal
// handling disposition...
- if (!(sa.handler () == ace_dispatcher
+ if (!(sa.handler () == ace_signal_handlers_dispatcher
|| sa.handler () == ACE_SignalHandler (SIG_IGN)
|| sa.handler () == ACE_SignalHandler (SIG_DFL)))
{
@@ -455,8 +457,8 @@ ACE_Sig_Handlers::register_handler (int signum,
delete ace_sig_adapter;
return -1;
}
- // If ACE_Sig_Handler::dispatch() was set we're done.
- else if (sa.handler () == ace_dispatcher)
+ // If ACE_Sig_Handlers::dispatch() was set we're done.
+ else if (sa.handler () == ace_signal_handlers_dispatcher)
return ace_sig_adapter->sigkey ();
// Otherwise, we need to register our handler function so that
@@ -468,7 +470,7 @@ ACE_Sig_Handlers::register_handler (int signum,
if (new_disp == 0)
new_disp = &sa;
- new_disp->handler (ace_dispatcher);
+ new_disp->handler (ace_signal_handlers_dispatcher);
// Default is to restart signal handlers.
new_disp->flags (new_disp->flags () | SA_RESTART);